/*
 *	Copyright (C) 2007. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvworker.h
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#ifndef	QVWORKER_H
#define	QVWORKER_H

#include <QApplication>
#include <QStringList>
#include <QMap>
#include <QSet>
#include <QThread> // PEDROE
#include <QTimer>// PEDROE

#include <qvcore/qvimage.h>
#include <qvcore/qvcamera.h>
#include <qvutils/cpustat.h>
#include <qvcore/qvpropertyholder.h>

/// \cond Not documented By now
class QVWorker: public QThread, public QVPropertyHolder
	{
	Q_OBJECT

	public:
		typedef enum
			{
			Running,
			RunningOneStep,
			Paused,
			Finished
			} TWorkerStatus;

		CpuStat cpuStat;

		QVWorker(QString name = QString());

		~QVWorker();

		/// @brief worker function.
		///
		/// insert explanation here.
		virtual void worker() = 0;

		bool isFinished() const				{ return status == Finished; }
		int getIteration() const			{ return numIterations; }
		TWorkerStatus getStatus() const			{ return status; }
		const QString getErrorStatusString() const	{ return errorStatus; }

	// These slots able the worker controller to modify it's state.
	// Both objects, QVWorker and QVController should be launched in the
	// same thread, for the QVControler object can emit those slots.
	public slots:
		void iterate();
		void pause()	{ qDebug() << "QVWorker::pause()"; status = Paused;		emit statusUpdate(status);	}
		void unPause()	{ qDebug() << "QVWorker::unPause()"; status = Running;		emit statusUpdate(status);	}
		void step()	{ qDebug() << "QVWorker::step()"; status = RunningOneStep;	emit statusUpdate(status);	}
		void finish()	{ qDebug() << "QVWorker::finish()"; status = Finished;		emit statusUpdate(status);	}

	// Signals (specially newFrame) are for notifying view objects state changes,
	// and new data generated by the worker.
	signals:
		//void iterateSignal();
		//void newFrame(const QString &, const QVImage<uChar,1> &);
		//void newFrame(const QString &, const QVImage<uChar,3> &);
		void startIteration();
		void endIteration();
		//void outputText(QString);
		void statusUpdate(QVWorker::TWorkerStatus);
		
	/*private:
		QTimer *timer;*/
	


	protected:
		int numIterations;
		TWorkerStatus status;
		bool inited;
		QMap<QString, bool> initedParam;
		QString errorStatus;
		QSet<QVCamera *> cameras;

		void run();

		void setErrorStatusString(const QString string)	{ errorStatus = string; }

		void timeFlag(const QString flag)
			{
			qDebug() << "QVWorker::timeFlag("<< flag <<")";
			cpuStat.setFlag(flag);
			}

		/*void parseArguments()
			{
			inited = true;
			QStringList arguments = qApp->arguments();
			QVPropertyHolder::parseArguments(arguments);
			}*/
	};
/// \endcond Not documented By now
#endif
