/*
 *	Copyright (C) 2007. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvimagecanvas.cpp
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <qvgui/qvimagecanvas.h>

QVImageCanvas::QVImageCanvas(const QString name, bool rgb, bool isFloat, int w,int h,QWidget *parent):
	QVCanvas(w,h,parent), QVPropertyHolder(), _rgb(rgb), _isFloat(isFloat),
	_low(0.0), _high(255.0)
	{
	setName("QVImageCanvas for "+name);
	setWindowTitle(getName());
	if(_rgb and not _isFloat)
		addProperty< QVImage<uChar,3> >("imageRGB", inputFlag, QVImage<uChar,3>(), "");
	else if(_rgb and _isFloat)
		std::cerr << "Warning: rgb-float images still not implemented in QVImageCanvas\n";
	else if(not _rgb and _isFloat)
		addProperty< QVImage<sFloat,1> >("imageGrayFloat", inputFlag, QVImage<uChar,1>(), "");
	else if(not _rgb and not _isFloat)
		addProperty< QVImage<uChar,1> >("imageGray", inputFlag, QVImage<uChar,1>(), "");
	};

void QVImageCanvas::viewer()
	{
	readInputProperties();
	qDebug() << "QVImageCanvas::viewer()";
	if (_rgb and not _isFloat)
		{
		QVImage<uChar,3> img = getPropertyValue<QVImage<uChar,3> >("imageRGB");
		getQVPainter()->drawQVImage(&img);
		}
	else if (not _rgb and not _isFloat)
		{
		QVImage<uChar,1> img = getPropertyValue<QVImage<uChar,1> >("imageGray");
		getQVPainter()->drawQVImage(&img);
		}
	else if (not _rgb and _isFloat)
		{
		QVImage<sFloat,1> img = getPropertyValue<QVImage<sFloat,1> >("imageGrayFloat");
		getQVPainter()->drawQVImage(&img,TRUE,_low,_high);
		}
	qDebug() << "QVImageCanvas::viewer() <~ return";
	}

void QVImageCanvas::setLowHigh(float low,float high)
	{
	_low = low;
	_high = high;
	}
