/*
 *	Copyright (C) 2007. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvparamsinspectorwidget.cpp
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <qvgui/qvparamsinspectorwidget.h>

QVParamsInspectorWidget::QVParamsInspectorWidget(QVPropertyHolder * object, QWidget *parent):QWidget(parent)
	{
	setGeometry(QRect(10, 20, 200, 0));

	vboxLayout = new QVBoxLayout(this);
	if (object != NULL)
		add(object);

	vboxLayout->addStretch();
	}

void QVParamsInspectorWidget::add(QVPropertyHolder *propertyHolder)
	{
	qDebug() << "QVParamsInspector::add()";

	//QSetIterator<QString> iter(* propertyHolder->getPropertyList());
	QListIterator<QString> iter(propertyHolder->getPropertyList());
	while (iter.hasNext())
		{
		QString property(iter.next());
		// Input properties will be visible:
		if(propertyHolder->isInput(property) and not propertyHolder->isLinkedInput(property))
			switch(propertyHolder->getPropertyType(property))
				{
				case QVariant::Double:
					qDebug() << "QVParamsInspector::add(): Double property"<< property;
					add(new QVDoubleParamWidget(propertyHolder, property));
					break;

				case QVariant::Int:
					qDebug() << "QVParamsInspector::add(): Int property"<< property;
					add(new QVIntParamWidget(propertyHolder, property));
					break;

				case QVariant::Bool:
					qDebug() << "QVParamsInspector::add(): Bool property"<< property;
					add(new QVBoolParamWidget(propertyHolder,property));
					break;

				default:
					break;
				};
		}
	qDebug() << "QVParamsInspector::add() <- return";
	}

void QVParamsInspectorWidget::add(QVIntParamWidget *widget)
	{
	vboxLayout->addWidget(widget);
	}

void QVParamsInspectorWidget::add(QVBoolParamWidget *widget)
	{
	vboxLayout->addWidget(widget);
	}

void QVParamsInspectorWidget::add(QVDoubleParamWidget *widget)
	{
	vboxLayout->addWidget(widget);
	}


